Descriptor class abstract

A declarative description of a filesystem entry.

This may be extended outside this package.

Implementers

Constructors

Descriptor(String name)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This entry's basename.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create([String? parent]) → Future<void>
Creates this entry within the parent directory, which defaults to sandbox.
describe() → String
Returns a human-friendly tree-style description of this descriptor.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate([String? parent]) → Future<void>
Validates that the physical file system under parent (which defaults to sandbox) contains an entry that matches this descriptor.

Operators

operator ==(Object other) → bool
The equality operator.
inherited