PatternDescriptor class
A descriptor that matches filesystem entity names by Pattern rather than by exact String.
This descriptor may only be used for validation.
- Inheritance
-
- Object
- Descriptor
- PatternDescriptor
Constructors
- PatternDescriptor(Pattern pattern, Descriptor child(String basename))
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This entry's basename.
finalinherited
- pattern → Pattern
-
The Pattern this matches filenames against. Note that the pattern must
match the entire basename of the file.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
[String? parent]) → Future< void> -
Creates this entry within the
parentdirectory, which defaults to sandbox.override -
describe(
) → String -
Returns a human-friendly tree-style description of this descriptor.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
[String? parent]) → Future< void> -
Validates that there is some filesystem entity in
parentthat matches pattern and the child entry. This finds all entities inparentmatching pattern, then passes each of their names tochildprovided in the constructor and validates the result. If exactly one succeeds,thisis considered valid.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited